==> svelte-preprocess-react-0.11.0.tgz: package/sveltify.js <==
import { createElement } from "react";
import { writable } from "svelte/store";
import ReactWrapper from "./internal/ReactWrapper.svelte";
import Slot from "./internal/Slot.svelte";
import Bridge, {} from "./internal/Bridge.js";
let rerender;
let autokey = 0;
const never = writable();
const target = writable();
const tree = {
    key: autokey,
    svelteInstance: never,
    reactComponent: ({ children }) => children,
    target,
    props: writable({}),
    slot: never,
    nodes: [],
    hooks: writable([]),
};
/**
 * Convert a React component into a Svelte component.
 */
export default function sveltify(reactComponent, createPortal, ReactDOMClient, renderToString) {
    const Wrapper = ReactWrapper;
    const ssr = typeof Wrapper.$$render === "function";
    if (ssr) {
        const { $$render } = Slot;
        return {
            ...Slot,
            $$render(result, props, bindings, slots, context) {
                if (!renderToString) {
                    return "";
                }
                const html = $$render.call(Slot, result, {}, bindings, slots, context);
                const vdom = html
                    ? createElement(reactComponent, props, createElement("svelte-slot", {
                        dangerouslySetInnerHTML: { __html: html },
                    }))
                    : createElement(reactComponent, props);
                return renderToString(vdom);
            },
        };
    }
    if (!rerender) {
        const rootEl = document.createElement("react-root");
        const root = ReactDOMClient.createRoot?.(rootEl);
        const targetEl = document.createElement("bridge-root");
        target.set(targetEl);
        document.head.appendChild(rootEl);
        document.head.appendChild(targetEl);
        if (root) {
            rerender = (props) => {
                root.render(createElement(Bridge, props));
            };
        }
        else {
            rerender = (props) => {
                ReactDOMClient.render(createElement(Bridge, props), rootEl);
            };
        }
    }
    function Sveltified(options) {
        const svelteInstance = writable();
        const instance = new ReactWrapper({
            ...options,
            props: {
                svelteInit(init) {
                    autokey += 1;
                    const node = {
                        key: autokey,
                        svelteInstance,
                        reactComponent,
                        props: init.props,
                        slot: init.slot,
                        target: init.target,
                        hooks: init.hooks,
                        nodes: [],
                    };
                    const parent = init.parent ?? tree;
                    parent.nodes.push(node);
                    rerender({ createPortal, node: tree });
                    init.onDestroy(() => {
                        parent.nodes = parent.nodes.filter((n) => n.svelteInstance !== svelteInstance);
                        rerender({ createPortal, node: tree });
                    });
                    return node;
                },
                ...options.props,
            },
        });
        svelteInstance.set(instance);
        return instance;
    }
    return Sveltified;
}

==> svelte-preprocess-react-0.12.0.tgz: package/sveltify.js <==
import * as React from "react";
import { writable } from "svelte/store";
import ReactWrapper from "./internal/ReactWrapper.svelte";
import Slot from "./internal/Slot.svelte";
import Bridge, {} from "./internal/Bridge.js";
let rerender;
let autokey = 0;
const never = writable();
const target = writable();
const tree = {
    key: autokey,
    svelteInstance: never,
    reactComponent: ({ children }) => children,
    target,
    props: writable({}),
    slot: never,
    nodes: [],
    hooks: writable([]),
};
/**
 * Convert a React component into a Svelte component.
 */
export default function sveltify(reactComponent, createPortal, ReactDOMClient, renderToString) {
    const Wrapper = ReactWrapper;
    const ssr = typeof Wrapper.$$render === "function";
    if (ssr) {
        const { $$render } = Slot;
        return {
            ...Slot,
            $$render(result, props, bindings, slots, context) {
                if (!renderToString) {
                    return "";
                }
                const html = $$render.call(Slot, result, {}, bindings, slots, context);
                const vdom = html
                    ? React.createElement(reactComponent, props, React.createElement("svelte-slot", {
                        dangerouslySetInnerHTML: { __html: html },
                    }))
                    : React.createElement(reactComponent, props);
                return renderToString(vdom);
            },
        };
    }
    if (!rerender) {
        const rootEl = document.createElement("react-root");
        const root = ReactDOMClient.createRoot?.(rootEl);
        const targetEl = document.createElement("bridge-root");
        target.set(targetEl);
        document.head.appendChild(rootEl);
        document.head.appendChild(targetEl);
        if (root) {
            rerender = (props) => {
                root.render(React.createElement(Bridge, props));
            };
        }
        else {
            rerender = (props) => {
                ReactDOMClient.render(React.createElement(Bridge, props), rootEl);
            };
        }
    }
    function Sveltified(options) {
        const svelteInstance = writable();
        const instance = new ReactWrapper({
            ...options,
            props: {
                svelteInit(init) {
                    autokey += 1;
                    const node = {
                        key: autokey,
                        svelteInstance,
                        reactComponent,
                        props: init.props,
                        slot: init.slot,
                        target: init.target,
                        hooks: init.hooks,
                        nodes: [],
                    };
                    const parent = init.parent ?? tree;
                    parent.nodes.push(node);
                    rerender({ createPortal, node: tree });
                    init.onDestroy(() => {
                        parent.nodes = parent.nodes.filter((n) => n.svelteInstance !== svelteInstance);
                        rerender({ createPortal, node: tree });
                    });
                    return node;
                },
                ...options.props,
            },
        });
        svelteInstance.set(instance);
        return instance;
    }
    return Sveltified;
}
